@@ -8,7 +8,6 @@ Created on Wed Oct 31 16:23:13 2018
 # system imports
 import sys
 import os
-import platform
 import time
 from subprocess import Popen
 from datetime import timedelta, datetime
@@ -19,13 +18,12 @@ import click
 from PyQt5 import QtCore, QtWidgets, QtGui
 
 # maestral modules
-from maestral import __version__
 from maestral.constants import (
     IDLE,
     SYNCING,
     PAUSED,
-    STOPPED,
-    DISCONNECTED,
+    CONNECTING,
+    CONNECTED,
     SYNC_ERROR,
     ERROR,
 )
@@ -43,7 +41,7 @@ from maestral_qt.relink_dialog import RelinkDialog
 from maestral_qt.settings_window import SettingsWindow
 from maestral_qt.activity_window import ActivityWindow
 from maestral_qt.sync_issues_window import SyncIssueWindow
-from maestral_qt.resources import system_tray_icon, DESKTOP, APP_ICON_PATH
+from maestral_qt.resources import system_tray_icon, APP_ICON_PATH
 from maestral_qt.utils import (
     BackgroundTask,
     MaestralBackgroundTask,
@@ -77,8 +75,8 @@ class MaestralGuiApp(QtWidgets.QSystemTrayIcon):
         IDLE: "idle",
         SYNCING: "syncing",
         PAUSED: "paused",
-        STOPPED: "error",
-        DISCONNECTED: "disconnected",
+        CONNECTED: "idle",
+        CONNECTING: "disconnected",
         SYNC_ERROR: "info",
         ERROR: "error",
     }
@@ -108,7 +106,7 @@ class MaestralGuiApp(QtWidgets.QSystemTrayIcon):
         self.autostart = AutoStart(self.config_name)
 
         self.icons = self.load_tray_icons()
-        self.setIcon(DISCONNECTED)
+        self.setIcon(CONNECTING)
         self.show_when_systray_available()
 
         self.menu = QtWidgets.QMenu()
@@ -397,10 +395,10 @@ class MaestralGuiApp(QtWidgets.QSystemTrayIcon):
     def on_start_stop_clicked(self):
         """Pause / resume syncing on menu item clicked."""
         if self.pauseAction.text() == self.PAUSE_TEXT:
-            self.mdbx.pause_sync()
+            self.mdbx.stop_sync()
             self.pauseAction.setText(self.RESUME_TEXT)
         elif self.pauseAction.text() == self.RESUME_TEXT:
-            self.mdbx.resume_sync()
+            self.mdbx.start_sync()
             self.pauseAction.setText(self.PAUSE_TEXT)
         elif self.pauseAction.text() == "Start Syncing":
             self.mdbx.start_sync()
@@ -469,14 +467,10 @@ class MaestralGuiApp(QtWidgets.QSystemTrayIcon):
         n_sync_errors = len(self.mdbx.sync_errors)
         status = self.mdbx.status
         is_paused = self.mdbx.paused
-        is_stopped = not self.mdbx.running
+        is_connected = self.mdbx.connected
 
         # update icon
-        if is_paused:
-            new_icon = PAUSED
-        elif is_stopped:
-            new_icon = ERROR
-        elif n_sync_errors > 0 and status == IDLE:
+        if n_sync_errors > 0 and status == IDLE:
             new_icon = SYNC_ERROR
         else:
             new_icon = status
@@ -533,7 +527,7 @@ class MaestralGuiApp(QtWidgets.QSystemTrayIcon):
         elif "MaestralApiError" in err["inherits"] or "SyncError" in err["inherits"]:
             show_dialog(err["title"], err["message"], level="error")
         else:
-            self._exec_stacktrace_dialog(err)
+            show_stacktrace_dialog(err["traceback"])
 
     def _exec_relink_dialog(self, reason):
 
@@ -542,45 +536,15 @@ class MaestralGuiApp(QtWidgets.QSystemTrayIcon):
         relink_dialog.show()
         relink_dialog.exec_()
 
-    def _exec_stacktrace_dialog(self, err):
-
-        share, auto_share = show_stacktrace_dialog(
-            err["traceback"], ask_share=not self.mdbx.analytics
-        )
-
-        if share:
-            import bugsnag
-
-            bugsnag.configure(
-                api_key="081c05e2bf9730d5f55bc35dea15c833",
-                app_version=__version__,
-                auto_notify=False,
-                auto_capture_sessions=False,
-            )
-            bugsnag.notify(
-                RuntimeError(err["type"]),
-                meta_data={
-                    "system": {
-                        "platform": platform.platform(),
-                        "python": platform.python_version(),
-                        "gui": f"Qt {QtCore.PYQT_VERSION_STR}",
-                        "desktop": DESKTOP,
-                    },
-                    "original exception": err,
-                },
-            )
-
-        self.mdbx.analytics = self.mdbx.analytics or auto_share
-
     def contextMenuVisible(self):
         return self._context_menu_visible
 
     def quit(self, *args, stop_daemon=None):
         """Quits Maestral.
 
-        :param bool stop_daemon: If ``True``, the sync daemon will be stopped when
+        :param bool stop_daemon: If ``True``, the sync daemon will be PAUSED when
             quitting the GUI, if ``False``, it will be kept alive. If ``None``, the
-            daemon will only be stopped if it was started by the GUI (default).
+            daemon will only be PAUSED if it was started by the GUI (default).
         """
 
         self._wait_for_status.cancel()
